@@ -15,7 +15,8 @@ import traceback
 
 class IsassEventHandler(FileSystemEventHandler):
     extension = '.sass'
-    def __init__(self,outfile,dirs,files=None,lib_dirs = None):
+
+    def __init__(self, outfile, dirs, files=None, lib_dirs = None):
         self.outfile = outfile
         self.dirs = dirs
         self.lib_dirs = lib_dirs if lib_dirs else []
@@ -60,9 +61,6 @@ class IsassEventHandler(FileSystemEventHandler):
                 changed = True
                 break
 
-
-        #paths = [p for p in paths if p.endswith(self.extension)]
-
         if changed:
             # One or more sass file changes, trying to regenerate output
             self.write_out()
@@ -90,6 +88,8 @@ class SassObserver(Observer):
         if files:
             watch_dirs += split_paths([os.path.dirname(p) for p in files])
 
+        watch_dirs = [wd for wd in distinct(watch_dirs) if os.path.exists(wd)]
+
         handler.write_out()
         for d in watch_dirs:
             self.schedule(handler, d, recursive=False)
